==> haskell-openpgp-asciiarmor-0.1.1-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openpgp-asciiarmor
version: 0.1.1
id: openpgp-asciiarmor-0.1.1-6guRLmDjmJLs60Lgx2xEA
key: openpgp-asciiarmor-0.1.1-6guRLmDjmJLs60Lgx2xEA
license: ISC
copyright: 2012-2018 Clint Adams
maintainer: Clint Adams <clint@debian.org>
author: Clint Adams
homepage: http://floss.scru.org/openpgp-asciiarmor
synopsis: OpenPGP (RFC4880) ASCII Armor codec
description:
    OpenPGP (RFC4880) ASCII Armor codec
category: Codec, Data
abi: 1dac89009838418028bf1ae4df04f98f
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types
hidden-modules: Data.Digest.CRC24
                Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
                Codec.Encryption.OpenPGP.ASCIIArmor.Utils
import-dirs: /usr/lib/ghc-8.6.3/site-local/openpgp-asciiarmor-0.1.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/openpgp-asciiarmor-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/openpgp-asciiarmor-0.1.1
hs-libraries: HSopenpgp-asciiarmor-0.1.1-6guRLmDjmJLs60Lgx2xEA
depends:
    attoparsec-0.13.2.2-Jk4D4QRG8ZrHQCpZMillSF base-4.12.0.0
    base64-bytestring-1.0.0.2-CfmN7HHNI1H5uoKJdmo0jp binary-0.8.6.0
    bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock
haddock-html: /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openpgp-asciiarmor-0.1.1-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openpgp-asciiarmor
version: 0.1.1
id: openpgp-asciiarmor-0.1.1-Jd4A1L5G9SAEILo7GkRTPZ
key: openpgp-asciiarmor-0.1.1-Jd4A1L5G9SAEILo7GkRTPZ
license: ISC
copyright: 2012-2018 Clint Adams
maintainer: Clint Adams <clint@debian.org>
author: Clint Adams
homepage: http://floss.scru.org/openpgp-asciiarmor
synopsis: OpenPGP (RFC4880) ASCII Armor codec
description:
    OpenPGP (RFC4880) ASCII Armor codec
category: Codec, Data
abi: 79d2b796fc8207476b9055e7035e1c86
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types
hidden-modules: Data.Digest.CRC24
                Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
                Codec.Encryption.OpenPGP.ASCIIArmor.Utils
import-dirs: /usr/lib/ghc-8.6.3/site-local/openpgp-asciiarmor-0.1.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/openpgp-asciiarmor-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/openpgp-asciiarmor-0.1.1
hs-libraries: HSopenpgp-asciiarmor-0.1.1-Jd4A1L5G9SAEILo7GkRTPZ
depends:
    attoparsec-0.13.2.2-5xLw3754VYU1jRp4MrlfX3 base-4.12.0.0
    base64-bytestring-1.0.0.2-CfmN7HHNI1H5uoKJdmo0jp binary-0.8.6.0
    bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock
haddock-html: /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
